package com.ruoyi.record.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.record.mapper.RecordInspectionCabinetMapper;
import com.ruoyi.record.domain.RecordInspectionCabinet;
import com.ruoyi.record.service.IRecordInspectionCabinetService;

/**
 * 电柜巡检记录Service业务层处理
 * 
 * @author zangch
 * @date 2024-11-07
 */
@Service
public class RecordInspectionCabinetServiceImpl implements IRecordInspectionCabinetService 
{
    @Autowired
    private RecordInspectionCabinetMapper recordInspectionCabinetMapper;

    /**
     * 查询电柜巡检记录
     * 
     * @param objId 电柜巡检记录主键
     * @return 电柜巡检记录
     */
    @Override
    public RecordInspectionCabinet selectRecordInspectionCabinetByObjId(Long objId)
    {
        return recordInspectionCabinetMapper.selectRecordInspectionCabinetByObjId(objId);
    }

    /**
     * 查询电柜巡检记录列表
     * 
     * @param recordInspectionCabinet 电柜巡检记录
     * @return 电柜巡检记录
     */
    @Override
    public List<RecordInspectionCabinet> selectRecordInspectionCabinetList(RecordInspectionCabinet recordInspectionCabinet)
    {
        return recordInspectionCabinetMapper.selectRecordInspectionCabinetList(recordInspectionCabinet);
    }

    /**
     * 新增电柜巡检记录
     * 
     * @param recordInspectionCabinet 电柜巡检记录
     * @return 结果
     */
    @Override
    public int insertRecordInspectionCabinet(RecordInspectionCabinet recordInspectionCabinet)
    {
        return recordInspectionCabinetMapper.insertRecordInspectionCabinet(recordInspectionCabinet);
    }

    /**
     * 修改电柜巡检记录
     * 
     * @param recordInspectionCabinet 电柜巡检记录
     * @return 结果
     */
    @Override
    public int updateRecordInspectionCabinet(RecordInspectionCabinet recordInspectionCabinet)
    {
        return recordInspectionCabinetMapper.updateRecordInspectionCabinet(recordInspectionCabinet);
    }

    /**
     * 批量删除电柜巡检记录
     * 
     * @param objIds 需要删除的电柜巡检记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordInspectionCabinetByObjIds(Long[] objIds)
    {
        return recordInspectionCabinetMapper.deleteRecordInspectionCabinetByObjIds(objIds);
    }

    /**
     * 删除电柜巡检记录信息
     * 
     * @param objId 电柜巡检记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordInspectionCabinetByObjId(Long objId)
    {
        return recordInspectionCabinetMapper.deleteRecordInspectionCabinetByObjId(objId);
    }
}
